@@ -5,7 +5,8 @@ from os import \
 
 from os.path import \
     join as pjoin, \
-    expanduser, isdir, isfile, dirname
+    expanduser, isdir, \
+    basename, isfile, dirname
 
 from socket import \
     socket as sock, \
@@ -406,18 +407,14 @@ def main():
 		makedirs(cacdir)
 	except FileExistsError:
 		pass
-	if not isfile('%s/pavlovadm.conf'%cfgdir):
-		with open('/usr/local/share/pavlovadm/pavlovadm.conf', 'r') as lfh, open('%s/pavlovadm.conf'%cfgdir, 'w+') as gfh:
-			gfh.write(lfh.read())
-	if not isfile('%s/Games.ini'%cfgdir):
-		with open('/usr/local/share/pavlovadm/Game.ini', 'r') as lfh, open('%s/Game.ini'%cfgdir, 'w+') as gfh:
-			gfh.write(lfh.read())
-	if not isfile('%s/public.ini'%cfgdir):
-		with open('/usr/local/share/pavlovadm/public.ini', 'r') as lfh, open('%s/public.ini'%cfgdir, 'w+') as gfh:
-			gfh.write(lfh.read())
-	if not isfile('%s/BalancingTable.csv'%cfgdir):
-		with open('/usr/local/share/pavlovadm/BalancingTable.csv', 'r') as lfh, open('%s/BalancingTable.csv'%cfgdir, 'w+') as gfh:
-			gfh.write(lfh.read())
+	src = '~/.local/share/pavlovadm'
+	if not isdir(src):
+		src = '/usr/local/share/pavlovadm'
+	if isdir(src):
+		for f in ('~/.local/share/pavlovadm/pavlovadm.conf', '~/.local/share/pavlovadm/Game.ini', '~/.local/share/pavlovadm/public.ini', '~/.local/share/pavlovadm/BalancingTable.csv'):
+			if not isfile('%s/%s'%(cfgdir, basename(f))):
+				with open(expanduser(f), 'r') as lfh, open('%s/%s'%(cfgdir, basename(f)), 'w+') as gfh:
+					gfh.write(lfh.read())
 	cfgs = config('%s/%s.conf'%(__me, __me))
 
 	pars = ArgumentParser(description=__dsc)
